Struct Source 

pub struct Source { /* private fields */ }
Represents source text that can be indexed into to define individual Spans.

Implementations

Source

impl Source

pub fn source_text(&self) -> IndexedSlice<'_>

Returns the underlying text of this Source, with original formatting.

pub fn from_str(string: impl AsRef<str>) -> Self

Creates a new Source from a string.

pub fn from_indexed_string(text: IndexedString) -> Self

Creates a new Source from an IndexedString.

pub fn from_file(path: impl AsRef<Path>) -> Result<Self, Error>

Reads the contents of a file and returns a Source with the file’s text.

Since no parsing is done at this stage, only IO or encoding errors will be returned, regardless of the validity of the syntax in the file.

pub fn set_path(&mut self, path: Option<impl AsRef<Path>>)

Sets the path of the file that this Source was read from.

pub fn source_path(&self) -> Option<&Path>

Returns the path of the file that this Source was read from, if it was read from a file.